--
-- LemkenGigant1400
-- Specialization for LemkenGigant1400
--
-- @author  Geri-G
-- @date  18.07.2011
-- @web www.geri-g.de
--
-- Copyright (C) Geri-G, All Rights Reserved.

--

LemkenGigant1400 = {};

function LemkenGigant1400.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Cultivator, specializations);
end;

function LemkenGigant1400:load(xmlFile)
	self.animations["UnTransport"].currentSpeed = -self.animations["UnTransport"].currentSpeed;
	self.animations["Lower"].currentSpeed = -self.animations["Lower"].currentSpeed;
	self.isLowered = LemkenGigant1400.isLowered;
	self.editAktivState = false;
	
end;


function LemkenGigant1400:readStream(streamId, connection)
	local isLowered = streamReadBool(streamId);
	local isTransport = streamReadBool(streamId);
	if not isTransport then
		self:playAnimation("UnTransport", 1,nil,true);
	end;
	if isLowered then
		self:playAnimation("Lower", 1,nil,true);
	end;
end;

function LemkenGigant1400:writeStream(streamId, connection)
	streamWriteBool(streamId, self:getAnimationTime("Lower") ~= 0);
	streamWriteBool(streamId, self:getAnimationTime("UnTransport") == 0);
end;

function LemkenGigant1400:keyEvent(unicode, sym, modifier, isDown)

end;


function LemkenGigant1400:update(dt)
	if self:getIsActiveForInput() then
		if InputBinding.hasEvent(InputBinding.LemkenGigant1400_Transport) and self:getAnimationTime("Lower") == 0 and table.getn(self.attachedImplements) <=0 then
			local anim = self.animations["UnTransport"];
			local animTime = anim.currentTime/anim.duration;
			self:playAnimation("UnTransport", -anim.currentSpeed,animTime);
		end;		
		if InputBinding.hasEvent(InputBinding.LemkenGigant1400_lower)and self:getAnimationTime("UnTransport") == 1 then
			local anim = self.animations["Lower"];
			local animTime = anim.currentTime/anim.duration;
			self:playAnimation("Lower", -anim.currentSpeed,animTime);
			self.editAktivState = true;
		end;
        -- do all the input handling
        if InputBinding.hasEvent(InputBinding.SWITCH_IMPLEMENT2) then
            local selected = self.selectedImplement;
            local numImplements = table.getn(self.attachedImplements);
            if selected ~= 0 and numImplements > 1 then
                selected = selected+1;
                if selected > numImplements then
                    selected = 1;
                end;
                self:setSelectedImplement(selected);
            end;
        end;

	end;
	if self:getIsActive() and self.editAktivState and self:getAnimationTime("Lower") >0.9 then
		for k,v in pairs(self.attachedImplements) do
			v.object:setIsTurnedOn(self.animations["Lower"].currentSpeed >0);
		end;		
		self.editAktivState = false;
	end;
end;
function LemkenGigant1400:isLowered(default)
    return self:getAnimationTime("Lower") >= 0.8 and self:getAnimationTime("UnTransport") == 1;
end;

function LemkenGigant1400:onAttach()

end; 


function LemkenGigant1400:onDetach()

end;	


function LemkenGigant1400:draw()		
	if self:getIsActiveForInput() then
		local anim1 = self:getAnimationTime("Lower");
		local anim1P = self:getIsAnimationPlaying("Lower");
		local anim2 = self:getAnimationTime("UnTransport");
		local anim2P = self:getIsAnimationPlaying("UnTransport");

		if anim2 == 1 or (self.animations["UnTransport"].currentSpeed > 0 and anim2P)  then		
			if anim1 ==0 and table.getn(self.attachedImplements) <=0  then
				g_currentMission:addHelpButtonText(g_i18n:getText("LemkenGigant1400_TransportT"),InputBinding.LemkenGigant1400_Transport);
			end;
			if anim2 == 1 then		
				if anim2 == 1 then
					if anim1 == 0 or (self.animations["Lower"].currentSpeed < 0 and anim1P) then
						g_currentMission:addHelpButtonText(g_i18n:getText("LemkenGigant1400_lowerT"),InputBinding.LemkenGigant1400_lower);
					elseif anim1==1 or (self.animations["Lower"].currentSpeed > 0 and anim1P) then
						g_currentMission:addHelpButtonText(g_i18n:getText("LemkenGigant1400_raiseT"),InputBinding.LemkenGigant1400_lower);				
					end;
				end;
			end;
		elseif anim2 == 0 or (self.animations["UnTransport"].currentSpeed <0 and anim2P) then
			g_currentMission:addHelpButtonText(g_i18n:getText("LemkenGigant1400_UnTransportT"),InputBinding.LemkenGigant1400_Transport);
		end;
		if g_currentMission.controlledVehicle ~= nil and g_currentMission.isRunning and g_gui.currentGui == nil then
			if g_currentMission.attachableInMountRange ~= nil then
				local vehicle = g_currentMission.attachableInMountRangeVehicle;
				local isJointFree = vehicle.attacherJoints[g_currentMission.attachableInMountRangeIndex].jointIndex == 0;
				if vehicle ~= nil and isJointFree then
					g_currentMission.hudAttachmentOverlay:render();
				end;
			end;
		end;
		g_currentMission:addHelpButtonText(g_i18n:getText("Change_tools2"),InputBinding.SWITCH_IMPLEMENT2);
	end;
end;


function LemkenGigant1400:delete()
	
end;



function LemkenGigant1400:mouseEvent(posX, posY, isDown, isUp, button)
end;


function LemkenGigant1400:aiLower()
	if self:getAnimationTime("UnTransport") == 1 then
		local anim = self.animations["Lower"];
		local animTime = anim.currentTime/anim.duration;
		self:playAnimation("Lower", 1,animTime);
	end;
end; 


function LemkenGigant1400:aiRaise()
	if self:getAnimationTime("UnTransport") == 1 then
		local anim = self.animations["Lower"];
		local animTime = anim.currentTime/anim.duration;
		self:playAnimation("Lower", -1,animTime);
	end;
end;